# coding: utf-8

"""
    AssistedInstall

    Assisted installation  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ApiVip(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cluster_id': 'str',
        'ip': 'Ip',
        'verification': 'VipVerification'
    }

    attribute_map = {
        'cluster_id': 'cluster_id',
        'ip': 'ip',
        'verification': 'verification'
    }

    def __init__(self, cluster_id=None, ip=None, verification=None):  # noqa: E501
        """ApiVip - a model defined in Swagger"""  # noqa: E501

        self._cluster_id = None
        self._ip = None
        self._verification = None
        self.discriminator = None

        if cluster_id is not None:
            self.cluster_id = cluster_id
        if ip is not None:
            self.ip = ip
        if verification is not None:
            self.verification = verification

    @property
    def cluster_id(self):
        """Gets the cluster_id of this ApiVip.  # noqa: E501

        The cluster that this VIP is associated with.  # noqa: E501

        :return: The cluster_id of this ApiVip.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """Sets the cluster_id of this ApiVip.

        The cluster that this VIP is associated with.  # noqa: E501

        :param cluster_id: The cluster_id of this ApiVip.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def ip(self):
        """Gets the ip of this ApiVip.  # noqa: E501

        The IP address.  # noqa: E501

        :return: The ip of this ApiVip.  # noqa: E501
        :rtype: Ip
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this ApiVip.

        The IP address.  # noqa: E501

        :param ip: The ip of this ApiVip.  # noqa: E501
        :type: Ip
        """

        self._ip = ip

    @property
    def verification(self):
        """Gets the verification of this ApiVip.  # noqa: E501

        API VIP verification result.  # noqa: E501

        :return: The verification of this ApiVip.  # noqa: E501
        :rtype: VipVerification
        """
        return self._verification

    @verification.setter
    def verification(self, verification):
        """Sets the verification of this ApiVip.

        API VIP verification result.  # noqa: E501

        :param verification: The verification of this ApiVip.  # noqa: E501
        :type: VipVerification
        """

        self._verification = verification

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiVip, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiVip):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
